@@ -17,14 +17,13 @@
  * by Manu Pathak (mapathak@cisco.com), May 2005
  */
 
-#define NETDISSECT_REWORKED
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include <tcpdump-stdinc.h>
+#include <netdissect-stdinc.h>
 
-#include "interface.h"
+#include "netdissect.h"
 #include "extract.h"
 #include "addrtoname.h"
 #include "gmpls.h"
@@ -459,14 +458,12 @@ lmp_print(netdissect_options *ndo,
                        ipaddr_string(ndo, obj_tptr),
                        EXTRACT_32BITS(obj_tptr)));
                 break;
-#ifdef INET6
             case LMP_CTYPE_IPV6_LOC:
             case LMP_CTYPE_IPV6_RMT:
                 ND_PRINT((ndo, "\n\t    IPv6 Link ID: %s (0x%08x)",
                        ip6addr_string(ndo, obj_tptr),
                        EXTRACT_32BITS(obj_tptr)));
                 break;
-#endif
             case LMP_CTYPE_UNMD_LOC:
             case LMP_CTYPE_UNMD_RMT:
                 ND_PRINT((ndo, "\n\t    Link ID: %u (0x%08x)",
@@ -551,9 +548,7 @@ lmp_print(netdissect_options *ndo,
                        EXTRACT_32BITS(obj_tptr+8)));
 		break;
 
-#ifdef INET6
 	    case LMP_CTYPE_IPV6:
-#endif
 	    case LMP_CTYPE_UNMD:
             default:
                 hexdump=TRUE;
@@ -620,9 +615,7 @@ lmp_print(netdissect_options *ndo,
 		}
 
 		break;
-#ifdef INET6
 	    case LMP_CTYPE_IPV6:
-#endif
             default:
                 hexdump=TRUE;
             }
@@ -709,9 +702,7 @@ lmp_print(netdissect_options *ndo,
 			offset+=8;
 		}
                 break;
-#ifdef INET6
 	    case LMP_CTYPE_IPV6:
-#endif
             default:
                 hexdump=TRUE;
             }
@@ -729,9 +720,7 @@ lmp_print(netdissect_options *ndo,
 			offset+=4;
 		}
                 break;
-#ifdef INET6
 	    case LMP_CTYPE_IPV6:
-#endif
 	    default:
                 hexdump=TRUE;
             }
