@@ -21,16 +21,15 @@
  * Format and print trivial file transfer protocol packets.
  */
 
-#define NETDISSECT_REWORKED
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include <tcpdump-stdinc.h>
+#include <netdissect-stdinc.h>
 
 #include <string.h>
 
-#include "interface.h"
+#include "netdissect.h"
 #include "extract.h"
 
 /*
@@ -131,7 +130,7 @@ tftp_print(netdissect_options *ndo,
 	case RRQ:
 	case WRQ:
 	case OACK:
-		p = (u_char *)tp->th_stuff;
+		p = (const u_char *)tp->th_stuff;
 		ND_PRINT((ndo, " "));
 		/* Print filename or first option */
 		if (opcode != OACK)
